@@ -228,7 +228,7 @@ static gboolean playercmd_stop(PlayerctlPlayer *player, gchar **argv, gint argc,
     GError *tmp_error = NULL;
     gchar *instance = pctl_player_get_instance(player);
 
-    // XXX there is no CanStop propery on the mpris player. CanPlay is supposed
+    // XXX there is no CanStop property on the mpris player. CanPlay is supposed
     // to indicate whether there is a current track. If there is no current
     // track, then I assume the player cannot stop.
     gboolean can_play = FALSE;
@@ -936,7 +936,7 @@ static int handle_list_all_flag() {
     }
 
     if (!one_selected && !no_status_error_messages) {
-        g_printerr("No players were found\n");
+        g_printerr("No players found\n");
     }
 
     pctl_player_name_list_destroy(player_names_list);
@@ -1103,6 +1103,7 @@ gint player_name_string_compare_func(gconstpointer a, gconstpointer b, gpointer
             if (any_index == INT_MAX) {
                 any_index = i;
             }
+            ++i;
             continue;
         }
 
