@@ -20,9 +20,10 @@
 #ifndef __PLAYERCTL_COMMON_H__
 #define __PLAYERCTL_COMMON_H__
 
-#include <glib.h>
 #include <gio/gio.h>
+#include <glib.h>
 #include <playerctl/playerctl.h>
+#include <stdbool.h>
 
 #define MPRIS_PREFIX "org.mpris.MediaPlayer2."
 
@@ -40,11 +41,9 @@ GBusType pctl_source_to_bus_type(PlayerctlSource source);
 
 PlayerctlSource pctl_bus_type_to_source(GBusType bus_type);
 
-PlayerctlPlayerName *pctl_player_name_new(const gchar *name,
-                                          PlayerctlSource source);
+PlayerctlPlayerName *pctl_player_name_new(const gchar *name, PlayerctlSource source);
 
-gint pctl_player_name_compare(PlayerctlPlayerName *name_a,
-                              PlayerctlPlayerName *name_b);
+gint pctl_player_name_compare(PlayerctlPlayerName *name_a, PlayerctlPlayerName *name_b);
 
 gint pctl_player_name_instance_compare(PlayerctlPlayerName *name, PlayerctlPlayerName *instance);
 
@@ -56,5 +55,9 @@ GList *pctl_player_name_find_instance(GList *list, gchar *player_id, PlayerctlSo
 
 void pctl_player_name_list_destroy(GList *list);
 
+GList *pctl_list_player_names_on_bus(GBusType bus_type, GError **err);
+
+bool pctl_player_has_cached_property(PlayerctlPlayer *player, const gchar *name);
+
 #undef __PLAYERCTL_COMMON_H__
 #endif
