@@ -93,7 +93,9 @@ static gboolean token_list_contains_key(GList *tokens, const gchar *key) {
             }
             break;
         case TOKEN_FUNCTION:
-            return token_list_contains_key(token->args, key);
+            if (token_list_contains_key(token->args, key)) {
+                return TRUE;
+            }
         default:
             break;
         }
@@ -481,14 +483,23 @@ static GVariant *helperfn_duration(struct token *token, GVariant **args, int nar
         return g_variant_new("s", "");
     }
 
-    // mpris durations are represented as int64 in microseconds
-    if (!g_variant_type_equal(g_variant_get_type(value), G_VARIANT_TYPE_INT64)) {
+    gint64 duration;
+
+    if (g_variant_type_equal(g_variant_get_type(value), G_VARIANT_TYPE_INT64)) {
+        // mpris specifies all track position values to be int64
+        duration = g_variant_get_int64(value);
+    } else if (g_variant_type_equal(g_variant_get_type(value), G_VARIANT_TYPE_UINT64)) {
+        // XXX: spotify may give uint64
+        duration = g_variant_get_uint64(value);
+    } else if (g_variant_type_equal(g_variant_get_type(value), G_VARIANT_TYPE_DOUBLE)) {
+        // only if supplied by a constant or position value type goes against spec
+        duration = g_variant_get_double(value);
+    } else {
         g_set_error(error, playerctl_formatter_error_quark(), 1,
-                    "function position can only be called on int64 values");
+                    "function duration can only be called on track position values");
         return NULL;
     }
 
-    gint64 duration = g_variant_get_int64(value);
     gint64 seconds = (duration / 1000000) % 60;
     gint64 minutes = (duration / 1000000 / 60) % 60;
     gint64 hours = (duration / 1000000 / 60 / 60);
@@ -608,15 +619,55 @@ static GVariant *helperfn_emoji(struct token *token, GVariant **args, int nargs,
     return value;
 }
 
+static GVariant *helperfn_trunc(struct token *token, GVariant **args, int nargs, GError **error) {
+    if (nargs != 2) {
+        g_set_error(error, playerctl_formatter_error_quark(), 1,
+                    "function trunc takes exactly two arguments (got %d)", nargs);
+        return NULL;
+    }
+
+    GVariant *value = args[0];
+    GVariant *len = args[1];
+    if (value == NULL || len == NULL) {
+        return g_variant_new("s", "");
+    }
+
+    if (!g_variant_type_equal(g_variant_get_type(len), G_VARIANT_TYPE_DOUBLE)) {
+        g_set_error(error, playerctl_formatter_error_quark(), 1,
+                    "function trunc's length parameter can only be called with an int");
+        return NULL;
+    }
+
+    gchar *orig = pctl_print_gvariant(value);
+    gchar *trunc = g_utf8_substring(orig, 0, g_variant_get_double(len));
+
+    GString *formatted = g_string_new(trunc);
+    if (g_utf8_strlen(trunc, 256) < g_utf8_strlen(orig, 256)) {
+        g_string_append(formatted, "…");
+    }
+
+    gchar *formatted_inner = g_string_free(formatted, FALSE);
+    GVariant *ret = g_variant_new("s", formatted_inner);
+    g_free(formatted_inner);
+    g_free(trunc);
+    g_free(orig);
+
+    return ret;
+}
+
 static gboolean is_valid_numeric_type(GVariant *value) {
     // This is all the types we know about for numeric operations. May be
-    // expanded at a later time.
+    // expanded at a later time. MPRIS only uses INT64 and DOUBLE as numeric
+    // types. Formatter constants are always DOUBLE. All other types are for
+    // player workarounds.
     if (value == NULL) {
         return FALSE;
     }
 
     if (g_variant_is_of_type(value, G_VARIANT_TYPE_INT64)) {
         return TRUE;
+    } else if (g_variant_is_of_type(value, G_VARIANT_TYPE_UINT64)) {
+        return TRUE;
     } else if (g_variant_is_of_type(value, G_VARIANT_TYPE_DOUBLE)) {
         return TRUE;
     }
@@ -625,8 +676,12 @@ static gboolean is_valid_numeric_type(GVariant *value) {
 }
 
 static gdouble get_double_value(GVariant *value) {
+    // Keep this in sync with above is_value_numeric_type()
+
     if (g_variant_is_of_type(value, G_VARIANT_TYPE_INT64)) {
         return (gdouble)g_variant_get_int64(value);
+    } else if (g_variant_is_of_type(value, G_VARIANT_TYPE_UINT64)) {
+        return (gdouble)g_variant_get_uint64(value);
     } else if (g_variant_is_of_type(value, G_VARIANT_TYPE_DOUBLE)) {
         return g_variant_get_double(value);
     } else {
@@ -830,6 +885,7 @@ struct template_function {
     {"markup_escape", &helperfn_markup_escape},
     {"default", &helperfn_default},
     {"emoji", &helperfn_emoji},
+    {"trunc", &helperfn_trunc},
     {INFIX_ADD, &infixfn_add},
     {INFIX_SUB, &infixfn_sub},
     {INFIX_MUL, &infixfn_mul},
